#
# spec file for package ncspot
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global rustflags '-Clink-arg=-Wl,-z,relro,-z,now'
%define _lto_cflags %{nil}
Name:           ncspot
Version:        1.3.0
Release:        1.1
Summary:        Cross-platform ncurses Spotify client written in Rust
Group:          Productivity/Multimedia/Sound/Players
License:        BSD-2-Clause
URL:            https://github.com/hrkfdn/ncspot
Source0:        %{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  cargo
BuildRequires:  cargo-packaging
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libssl)
BuildRequires:  pkgconfig(ncursesw)
BuildRequires:  pkgconfig(xcb)

%description
ncurses Spotify client written in Rust using librespot. It is heavily inspired by ncurses MPD clients, such as ncmpc. My motivation was to provide a simple and resource friendly alternative to the official client as well as to support platforms that currently don't have a Spotify client, such as the *BSDs.

%prep
%autosetup -a1

%build
%{cargo_build}

%install
%{cargo_install}
# install the desktop file
install -Dm 0644 misc/ncspot.desktop %{buildroot}/%{_datadir}/applications/ncspot.desktop
install -Dm 0644 images/logo.svg %{buildroot}/%{_datadir}/icons/hicolor/scalable/apps/ncspot.svg

%files
%license LICENSE
%doc README.md
%{_bindir}/ncspot
%{_datadir}/applications/ncspot.desktop
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/scalable/apps
%{_datadir}/icons/hicolor/scalable/apps/ncspot.svg

%changelog
* Sun Jul 13 2025 lorenzholzbauer@ikmail.com
- Update to version 1.3.0:
  * chore: Release prep for 1.3.0
  * chore(deps): bump the cargo group with 3 updates (#1664)
  * feat(auth): Automatically find free port
  * chore: `cargo clippy --fix`
  * [create-pull-request] automated change
  * chore(deps): bump the cargo group across 1 directory with 2 updates (#1661)
  * chore(deps): bump the cargo group with 6 updates (#1658)
  * fix: Do not crash due to unavailable tracks in queue
  * fix: Switch command line fg/bg colors
  * chore(deps): bump the cargo group across 1 directory with 4 updates (#1654)
  * docs: Update documentation links
  * chore(deps): bump the cargo group with 2 updates (#1646)
  * fix(queue): Don't freeze on item double click
  * chore(deps): bump zbus from 5.6.0 to 5.7.0 in the cargo group
  * fix: `cargo clippy --fix`
  * [create-pull-request] automated change
  * chore(deps): bump the cargo group with 4 updates
  * Prevent event loop starvation by unplayable tracks
  * chore: remove unused `rustfmt.toml` file
  * Added missing parenthesis
  * chore(deps): bump the cargo group across 1 directory with 9 updates
  * chore: `cargo clippy --fix`
  * [create-pull-request] automated change
  * chore(deps): bump crossbeam-channel from 0.5.14 to 0.5.15
  * chore(deps): bump openssl from 0.10.71 to 0.10.72
  * chore(deps): bump the cargo group with 3 updates
  * chore(deps): bump the cargo group across 1 directory with 5 updates
  * chore(deps): bump the cargo group with 4 updates
  * chore: Tweak log levels a little
  * fix: Skip unplayable tracks
  * feat(ci): Add nix-shell setup
  * chore(deps): bump the cargo group across 1 directory with 3 updates
  * chore: Update to edition 2024
  * chore(deps): bump the cargo group with 3 updates
  * chore(deps): bump ring from 0.17.8 to 0.17.13
  * chore: Remove unnecessary `take()` call
  * [create-pull-request] automated change
  * chore(deps): bump the cargo group with 6 updates
  * fix: Corrected incorrect comment
  * chore: other small fixes
  * chore: adapt to `rand` changes
  * chore(deps): bump the cargo group across 1 directory with 7 updates
  * chore(deps): bump openssl from 0.10.69 to 0.10.70
  * [create-pull-request] automated change
* Wed Feb  5 2025 Lorenz Holzbauer <lorenzholzbauer@ikmail.com>
- changed ncurses version
* Tue Feb  4 2025 Lorenz Holzbauer <lorenzholzbauer@ikmail.com>
- added rest of files
* Tue Feb  4 2025 Lorenz Holzbauer <lorenzholzbauer@ikmail.com>
- added obsinfo file for real
* Tue Feb  4 2025 Lorenz Holzbauer <lorenzholzbauer@ikmail.com>
- added obsinfo file
* Tue Feb  4 2025 lorenzholzbauer@ikmail.com
- Update to version 1.2.2:
  * chore: Bump version to 1.2.2
  * chore(deps): bump the cargo group with 2 updates
  * feat(ci): Lint + Build for aarch64 (#1581)
  * [create-pull-request] automated change
  * fix: Allow usage of deprecated related artists API
  * chore(deps): bump the cargo group across 1 directory with 10 updates
  * chore(deps): bump the cargo group with 2 updates
  * docs: remove remaining password manager documentation (#1573)
  * docs: add missing password manager removal to changelog (#1572)
  * feat: add %%artist formatting option
* Tue Feb  4 2025 Lorenz Holzbauer <lorenzholzbauer@ikmail.com>
- fixed broken build file
* Tue Feb  4 2025 lorenzholzbauer@ikmail.com
- Update to version 1.2.2:
  * chore: Bump version to 1.2.2
  * chore(deps): bump the cargo group with 2 updates
  * feat(ci): Lint + Build for aarch64 (#1581)
  * [create-pull-request] automated change
  * fix: Allow usage of deprecated related artists API
  * chore(deps): bump the cargo group across 1 directory with 10 updates
  * chore(deps): bump the cargo group with 2 updates
  * docs: remove remaining password manager documentation (#1573)
  * docs: add missing password manager removal to changelog (#1572)
  * feat: add %%artist formatting option
* Tue Feb  4 2025 lorenzholzbauer@ikmail.com
- Update to version 1.2.2:
  * chore: Bump version to 1.2.2
  * chore(deps): bump the cargo group with 2 updates
  * feat(ci): Lint + Build for aarch64 (#1581)
  * [create-pull-request] automated change
  * fix: Allow usage of deprecated related artists API
  * chore(deps): bump the cargo group across 1 directory with 10 updates
  * chore(deps): bump the cargo group with 2 updates
  * docs: remove remaining password manager documentation (#1573)
  * docs: add missing password manager removal to changelog (#1572)
  * feat: add %%artist formatting option
* Mon Feb  3 2025 Lorenz Holzbauer <lorenzholzbauer@ikmail.com>
- added icon
* Sat Jan  6 2024 Jan-Luca Kiok <opensuse-packages@jlk.one>
- Change required rust build version to 1.70
* Sat Jan  6 2024 Jan-Luca Kiok <opensuse-packages@jlk.one>
- Build via cargo packaging
* Sat Jan  6 2024 Jan-Luca Kiok <opensuse-packages@jlk.one>
- Extend service to fetch and prepare package
- Update to version 1.0.0
  Added
  * Special color for unavailable items
  * Changelog with all the relevant user-facing changes to the
    project
  * info command line subcommand to show platform specific
    information
  Changed
  * Improve error messages generated by the command line
  * Build with crossterm terminal backend by default
  * Move UNIX IPC socket from the user's cache path to the user's
    runtime directory
  * Improve messages relating to errors in the configuration file
  Fixed
  * Crash when internal commands can't be handled
  * Documentation for the behavior of the Ctrl+S keybinding
  * Multiple instances interfering with each other's MPRIS
    implementation
  * An unlikely crash when the UNIX IPC socket is removed before
    ncspot is closed
  * Guaranteed crash while quiting ncspot when using MPRIS
  * MPRIS volume not being updated when given numbers smaller
    than 0 or larger than 1
  * Allow previous track via MPRIS if first track in queue is
    playing
* Thu Jul 27 2023 Jan-Luca Kiok <opensuse-packages@jlk.one>
- Update to version 0.13.4
  Features
  * Add save current command
  * Add add command for adding song to playlist
  Maintenance
  * Improve release build options
  * Fix: Forward mouse events inside layout
  * Refactor: remove unused screenchange variable
  * Update documentation: recommend Ueberzug++
  * Sort Artists Ignoring "The"
  * Fix: Gracefully handle local files
  * Fix: Speed up context menu by fetching album only once
* Sat Jun 17 2023 Jan-Luca Kiok <opensuse-packages@jlk.one>
- Update to version 0.13.3
  Maintenance
  * Fix incorrect notification ID reuse on XDG
  * Fix: ListView decrement selected on remove
  * Support multiple IPC sockets
  * Refactor the entry point to make it more readable
  * Fix: command line multi-byte prefix panic
  * Prevent tab switching from the command line
  * Fix: config option command_key not working
  * Remove Snapcraft installation source
  * Add cargo installation method
* Mon May 15 2023 Jan-Luca Kiok <opensuse-packages@jlk.one>
- Lock vendored dependencies
* Thu May 11 2023 Jan-Luca Kiok <opensuse-packages@jlk.one>
- Lock cargo installation
* Sun May  7 2023 Jan-Luca Kiok <opensuse-packages@jlk.one>
- Update to version 0.13.2
  Maintenance
  * Use notify-rust with zbus instead of dbus and add
    ncurses_backend feature flag
  * Fix: gracefully handle invalid/not available DBus setups
    causing crashes
  * Update Nerdfont glyphs
  * Dependency updates
* Sat Apr 15 2023 Jan-Luca Kiok <opensuse-packages@jlk.one>
- Update to version 0.13.1
  Maintenance
  * Disable ncspot default features for xtask to simplify build
  * Statusbar: Update nerdfont glyphs
  * Split up README
  * Add 'browse' to 'library_tabs' docs
  * Rewrite MPRIS implementation using zbus
  Features
  * Add vim-like page scrolling
  * Emulate double click to play items
* Fri Mar 10 2023 Jan-Luca Kiok <me@jlk.one>
- Remove check stage via cargo test
* Fri Mar 10 2023 Jan-Luca Kiok <me@jlk.one>
- Update to version 0.13.0
  Maintenance
  * Add info on extracting currently playing to README
  * Fix clippy warnings
  * Always pass cover URL to notification
  * Change unnecessary usage of Arc to borrow instead
  * Disable autojump for add to playlist dialog
  Features
  * Theme config support for Cursive's `HighlightInactive`
  * Switch from MM:SS to HH:MM:SS duration representation if needed
  * commands: Add "reconnect" command to force socket shutdown
  * Allow executing program to retrieve credentials
  * Add manpage generation using xtask
  * Automatic shell completion generation using xtask
- Switch to zst compression for vendored deps
- Use cargo test as check stage
* Fri Dec 30 2022 Jan-Luca Kiok <me@jlk.one>
- Update to version 0.12.0
  Maintenance
  * Fix: Handle explicit field from Spotify API
  * Print "Connecting to Spotify" before setting up Cursive backend
  * Link to Flatpak image
  * Make entry point synchronous and switch to global runtime
    instead
  * Document queue module
  Features
  * Add "save/unsave album" to context menu
  * Automatically save backtraces to cache folder
  * Create IPC socket on UNIX platforms for remote control and
    external track display
* Mon Oct 17 2022 Jan-Luca Kiok <me@jlk.one>
- Update to version 0.11.2
  Maintenance
  * Cleanup: Remove PlayTrackMenu
  * Fix: Crash on liked artist but no liked music
  Features
  * Improve context menus to make the UX/UI more consistent
  * Exit gracefully on SIGTERM and SIGHUP
* Sun Sep 18 2022 Jan-Luca Kiok <me@jlk.one>
- Update to version 0.11.1
  Maintenance
  * Fix theming in context menus
  * Fix ListView scrollbar behavior
  * Switch to Termion backend by default for true color support
  * Fix references to pancurses backend in README
  * Changes to README capitalized in playlists
  * Fixed clipboard not working on GNOME Wayland.by
  * Fix: don't crash on empty command line input
  * Other refactoring and cleanups
  * Fix back button mouse left click
  * Fix librespot audio cache path
  * Fix: set track position only for clicks, not hold
  * Fix: Use buffered backend to prevent flickering with Termion
  * Fix: remove broken album cache staleness detection
  * Fix: Re-request album tracks if it has >50 tracks
  * Fixed pagination bug that caused items not to load when
    scrolling with mouse
  * Fix pagination in "Browse" screen
  Features
  * Add category browsing to library
  * Add customization of notification message texts
  * Improved mouse support
  * Mouse wheel: scroll up/down without changing focus
* Sun Jul 31 2022 Jan-Luca Kiok <me@jlk.one>
- Update to version 0.10.1
  Maintenance
  * Add logo to cargo-deb assets
  * Clean up documentation
  * Enable wayland clipboard support by default on supported
    platforms
  * Update to librespot 0.4.2
  * Should fix ChannelError issues which were previously fixed
    with a workaround in /etc/hosts
  * Updated context menu info and config values table in README
  Features
  * Add 'hide_display_names' config option
  * Added possibility to Follow/Unfollow artists via the context
    menu
  * Add statusbar_format option to configure track formatting in
    status bar
* Mon Jun 20 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Sun Jun 12 2022 Jan-Luca Kiok <me@jlk.one>
- Package desktop file
* Sun Jun 12 2022 Jan-Luca Kiok <me@jlk.one>
- Depend on rust version 1.61
- Update to version 0.10.0
  Maintenance
  * Update to Librespot 0.4.1
  * Prevent integer overflow when calculating cache size
  * Fix some errors and warnings when enabling/disabling features
  * Fix: don't throw error if search yields no result
  Features
  * Add option (library_tabs) to customize library tabs
  * Add track_format config option for custom track formatting in
    lists
  * Add desktop entry & notification icon hint
* Tue May 24 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Sun May  1 2022 Jan-Luca Kiok <me@jlk.one>
- Update to version 0.9.8
  Maintenance
  * Disable compat feature in futures
  * Remove webbrowser crate
  * Only download cover image when flag enabled
  * Fix: do not crash DBus on invalid Spotify URIs
  Features
  * Add playback_state config option
  * Add option to play track from context menu dialog
- Do not strip binary via Cargo
* Thu Apr  7 2022 Jan-Luca Kiok <me@jlk.one>
- Format spec file via osc service
* Thu Mar 24 2022 Jan-Luca Kiok <me@jlk.one>
- Update to version 0.9.6
  * Fix error messages shown on successful commands
  * Notification improvements (update existing notification, set
    application name)
  * Dependency updates
* Wed Mar  9 2022 Jan-Luca Kiok <me@jlk.one>
- Require cargo version 1.58 at least for binary stripping on cargo
  build
* Wed Mar  9 2022 Jab-Luca Kiok <me@jlk.one>
- Strip binary
* Wed Mar  9 2022 Jan-Luca Kiok <me@jlk.one>
- Update to version 0.9.6
  Maintenance
  * Enable autojump for playlist selection list in context menu
  * Use notify-rust with dbus instead of zbus
  * Fix compilation on Rust versions < 1.58.0
  * Make album sorting case-insensitive
  * Enable gapless by default
  * Improve playlist sorting
  * Dependency updates
* Fri Jan 21 2022 Jan-Luca Kiok <me@jlk.one>
- Update to version 0.9.5
  Maintenance
  * Fix release build name and win32 feature
  * seek spits out correct error when used with no args
  * Migrate to cursive 0.17
  * Remove notifications' dependency on cover
  * Fix errors showing up even though the command was successful
  * Fix lists that were shown as empty even though they contained
    items
* Sat Jan 15 2022 Jan-Luca Kiok <me@jlk.one>
- Update to version 0.9.4
  Maintenance
  * Sort library after saving an album
  * Stop player when Spotify worker thread dies
  * Update librespot to 0.3.1
  * Major/breaking update to rspotify 0.11.3
  * Refactoring and other cleanups
  * Fix crash when saving track or opening similar tracks
  * Fixed MPRIS OpenUri function not respecting ncspot's shuffle
    setting
  * Fix queuing of playlists causing "play next" to be broken
  * More detailed error message in case of command parse error
  * Remove panics in the update_token flow
  Features
  * Add command to show recommendations
  * Enable binding multiple commands to a key
  * Add "Share album" contextmenu entry
  * Add redraw command and bind to CTRL+L
  * Add initial_screen config variable
  * Add userRating entity to MPRIS metadata
  * Show playlist owner name
  * Introduce cache file format version indicator.
  * Added Wayland clipboard support
  * Added jumpnext and jumpprevious as commands
  * Add exec command allowing users to execute shell commands on
    key press
  * Improved seek command to allow more units (e.g. 2s), check
    parse_duration documentation for accepted units
  * Set terminal title to ncspot
* Sat Aug 28 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.8.2
  Maintenance
  * Reduce API calls by only fetching the full track details if
    necessary
  * Refactoring, other cleanups and dependency updates
  * Remove broken Facebook login code (#310).
  Features
  * Scrolling on volume text increases/decreases volume.
* Sun Aug 22 2021 Martin Hauke <mardnh@gmx.de>
- Initial package, version 0.8.1
